OPAL: Offset Portfolio Analyzer and Locator
===========================================

A tool by the Natural Capital Project.

Visit http://naturalcapitalproject.org/OPAL.html for more information.
